Repository: incubator-ignite
Updated Branches:
  refs/heads/ignite-86 6e1aa2a53 -> 7cccef782


http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/indexing/src/test/java/org/apache/ignite/internal/processors/query/h2/GridH2IndexingGeoSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/indexing/src/test/java/org/apache/ignite/internal/processors/query/h2/GridH2IndexingGeoSelfTest.java
 
b/modules/indexing/src/test/java/org/apache/ignite/internal/processors/query/h2/GridH2IndexingGeoSelfTest.java
index a43c5f4..b53abd4 100644
--- 
a/modules/indexing/src/test/java/org/apache/ignite/internal/processors/query/h2/GridH2IndexingGeoSelfTest.java
+++ 
b/modules/indexing/src/test/java/org/apache/ignite/internal/processors/query/h2/GridH2IndexingGeoSelfTest.java
@@ -57,7 +57,7 @@ public class GridH2IndexingGeoSelfTest extends 
GridCacheAbstractSelfTest {
      */
     @SuppressWarnings("unchecked")
     public void testGeo() throws Exception {
-        GridCache<Integer, EnemyCamp> cache = grid(0).cache(null);
+        Cache<Integer, EnemyCamp> cache = grid(0).cache(null);
 
         WKTReader r = new WKTReader();
 
@@ -66,7 +66,7 @@ public class GridH2IndexingGeoSelfTest extends 
GridCacheAbstractSelfTest {
         cache.put(2, new EnemyCamp(r.read("POINT(70 30)"), "C"));
         cache.put(3, new EnemyCamp(r.read("POINT(75 25)"), "D"));
 
-        GridCacheQuery<Map.Entry<Integer, EnemyCamp>> qry = 
cache.queries().createSqlQuery(EnemyCamp.class,
+        CacheQuery<Map.Entry<Integer, EnemyCamp>> qry = 
cache.queries().createSqlQuery(EnemyCamp.class,
             "coords && ?");
 
         Collection<Map.Entry<Integer, EnemyCamp>> res = 
qry.execute(r.read("POLYGON((5 70, 5 80, 30 80, 30 70, 5 70))"))
@@ -113,9 +113,9 @@ public class GridH2IndexingGeoSelfTest extends 
GridCacheAbstractSelfTest {
      */
     @SuppressWarnings("unchecked")
     public void testGeoMultithreaded() throws Exception {
-        final GridCache<Integer, EnemyCamp> cache1 = grid(0).cache(null);
-        final GridCache<Integer, EnemyCamp> cache2 = grid(1).cache(null);
-        final GridCache<Integer, EnemyCamp> cache3 = grid(2).cache(null);
+        final Cache<Integer, EnemyCamp> cache1 = grid(0).cache(null);
+        final Cache<Integer, EnemyCamp> cache2 = grid(1).cache(null);
+        final Cache<Integer, EnemyCamp> cache3 = grid(2).cache(null);
 
         final String[] points = new String[CNT];
 
@@ -146,7 +146,7 @@ public class GridH2IndexingGeoSelfTest extends 
GridCacheAbstractSelfTest {
                 while (!stop.get()) {
                     int cacheIdx = rnd.nextInt(0, 3);
 
-                    GridCache<Integer, EnemyCamp> cache = cacheIdx == 0 ? 
cache1 : cacheIdx == 1 ? cache2 : cache3;
+                    Cache<Integer, EnemyCamp> cache = cacheIdx == 0 ? cache1 : 
cacheIdx == 1 ? cache2 : cache3;
 
                     int idx = rnd.nextInt(CNT);
                     int x = rnd.nextInt(1, 100);
@@ -171,9 +171,9 @@ public class GridH2IndexingGeoSelfTest extends 
GridCacheAbstractSelfTest {
                     try {
                         int cacheIdx = rnd.nextInt(0, 3);
 
-                        GridCache<Integer, EnemyCamp> cache = cacheIdx == 0 ? 
cache1 : cacheIdx == 1 ? cache2 : cache3;
+                        Cache<Integer, EnemyCamp> cache = cacheIdx == 0 ? 
cache1 : cacheIdx == 1 ? cache2 : cache3;
 
-                        GridCacheQuery<Map.Entry<Integer, EnemyCamp>> qry = 
cache.queries().createSqlQuery(
+                        CacheQuery<Map.Entry<Integer, EnemyCamp>> qry = 
cache.queries().createSqlQuery(
                             EnemyCamp.class, "coords && ?");
 
                         Collection<Map.Entry<Integer, EnemyCamp>> res = 
qry.execute(
@@ -229,11 +229,11 @@ public class GridH2IndexingGeoSelfTest extends 
GridCacheAbstractSelfTest {
      */
     private static class EnemyCamp implements Serializable {
         /** */
-        @GridCacheQuerySqlField(index = true)
+        @CacheQuerySqlField(index = true)
         private Geometry coords;
 
         /** */
-        @GridCacheQuerySqlField
+        @CacheQuerySqlField
         private String name;
 
         /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/indexing/src/test/java/org/apache/ignite/loadtests/h2indexing/GridTestEntity.java
----------------------------------------------------------------------
diff --git 
a/modules/indexing/src/test/java/org/apache/ignite/loadtests/h2indexing/GridTestEntity.java
 
b/modules/indexing/src/test/java/org/apache/ignite/loadtests/h2indexing/GridTestEntity.java
index 75a5a8f..39069f1 100644
--- 
a/modules/indexing/src/test/java/org/apache/ignite/loadtests/h2indexing/GridTestEntity.java
+++ 
b/modules/indexing/src/test/java/org/apache/ignite/loadtests/h2indexing/GridTestEntity.java
@@ -26,11 +26,11 @@ import java.util.*;
  */
 public class GridTestEntity {
     /** */
-    @GridCacheQuerySqlField(index = true)
+    @CacheQuerySqlField(index = true)
     private final String name;
 
     /** */
-    @GridCacheQuerySqlField(index = false)
+    @CacheQuerySqlField(index = false)
     private final Date date;
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/indexing/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/indexing/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
 
b/modules/indexing/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
index 16d3e7e..f76ae6f 100644
--- 
a/modules/indexing/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
+++ 
b/modules/indexing/src/test/java/org/apache/ignite/spi/communication/tcp/GridOrderedMessageCancelSelfTest.java
@@ -39,7 +39,7 @@ import java.util.concurrent.*;
 
 import static java.util.concurrent.TimeUnit.*;
 import static org.apache.ignite.cache.CacheMode.*;
-import static org.apache.ignite.cache.GridCachePreloadMode.*;
+import static org.apache.ignite.cache.CachePreloadMode.*;
 
 /**
  *
@@ -97,7 +97,7 @@ public class GridOrderedMessageCancelSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testQuery() throws Exception {
-        GridCacheQueryFuture<Map.Entry<Object, Object>> fut =
+        CacheQueryFuture<Map.Entry<Object, Object>> fut =
             grid(0).cache(null).queries().createSqlQuery(String.class, "_key 
is not null").execute();
 
         testMessageSet(fut);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheJtaSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheJtaSelfTest.java
 
b/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheJtaSelfTest.java
index 9502b64..8b67d68 100644
--- 
a/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheJtaSelfTest.java
+++ 
b/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheJtaSelfTest.java
@@ -148,9 +148,9 @@ public class GridCacheJtaSelfTest extends 
GridCacheAbstractSelfTest {
     public void _testJtaTwoCaches() throws Exception { // TODO GG-9141
         UserTransaction jtaTx = jotm.getUserTransaction();
 
-        GridCache<String, Integer> cache1 = cache();
+        Cache<String, Integer> cache1 = cache();
 
-        GridCache<String, Integer> cache2 = grid(0).cache("cache-2");
+        Cache<String, Integer> cache2 = grid(0).cache("cache-2");
 
         assertNull(cache1.tx());
         assertNull(cache2.tx());

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridTmLookupLifecycleAwareSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridTmLookupLifecycleAwareSelfTest.java
 
b/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridTmLookupLifecycleAwareSelfTest.java
index 7fd560f..e7d9d60 100644
--- 
a/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridTmLookupLifecycleAwareSelfTest.java
+++ 
b/modules/jta/src/test/java/org/apache/ignite/internal/processors/cache/GridTmLookupLifecycleAwareSelfTest.java
@@ -28,7 +28,7 @@ import org.jetbrains.annotations.*;
 
 import javax.transaction.*;
 
-import static org.apache.ignite.cache.GridCacheDistributionMode.*;
+import static org.apache.ignite.cache.CacheDistributionMode.*;
 import static org.apache.ignite.cache.CacheMode.*;
 
 /**
@@ -39,7 +39,7 @@ public class GridTmLookupLifecycleAwareSelfTest extends 
GridAbstractLifecycleAwa
     private static final String CACHE_NAME = "cache";
 
     /** */
-    private GridCacheDistributionMode distroMode;
+    private CacheDistributionMode distroMode;
 
     /**
      */
@@ -93,7 +93,7 @@ public class GridTmLookupLifecycleAwareSelfTest extends 
GridAbstractLifecycleAwa
 
     /** {@inheritDoc} */
     @Override public void testLifecycleAware() throws Exception {
-        for (GridCacheDistributionMode mode : new GridCacheDistributionMode[] 
{PARTITIONED_ONLY, NEAR_PARTITIONED}) {
+        for (CacheDistributionMode mode : new CacheDistributionMode[] 
{PARTITIONED_ONLY, NEAR_PARTITIONED}) {
             distroMode = mode;
 
             super.testLifecycleAware();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/scalar/src/main/scala/org/apache/ignite/scalar/ScalarConversions.scala
----------------------------------------------------------------------
diff --git 
a/modules/scalar/src/main/scala/org/apache/ignite/scalar/ScalarConversions.scala
 
b/modules/scalar/src/main/scala/org/apache/ignite/scalar/ScalarConversions.scala
index 77d212c..cbc1f5c 100644
--- 
a/modules/scalar/src/main/scala/org/apache/ignite/scalar/ScalarConversions.scala
+++ 
b/modules/scalar/src/main/scala/org/apache/ignite/scalar/ScalarConversions.scala
@@ -18,7 +18,7 @@
 package org.gridgain.scalar
 
 import org.apache.ignite.Ignite
-import org.apache.ignite.cache.{GridCacheEntry, GridCache, GridCacheProjection}
+import org.apache.ignite.cache.{CacheEntry, Cache, CacheProjection}
 import org.apache.ignite.cluster.ClusterGroup
 import org.apache.ignite.compute.ComputeJob
 import org.apache.ignite.lang._
@@ -269,8 +269,8 @@ trait ScalarConversions {
      *
      * @param p Cache KV-pair predicate to convert.
      */
-    implicit def toEntryPred[K, V](p: (K, V) => Boolean): (_ >: 
GridCacheEntry[K, V]) => Boolean =
-        (e: GridCacheEntry[K, V]) =>
+    implicit def toEntryPred[K, V](p: (K, V) => Boolean): (_ >: CacheEntry[K, 
V]) => Boolean =
+        (e: CacheEntry[K, V]) =>
             p(e.getKey, e.getValue)
 
     /**
@@ -393,19 +393,19 @@ trait ScalarConversions {
         ScalarProjectionPimp(impl)
 
     /**
-     * Implicit converter from `GridCache` to `ScalarCachePimp` "pimp".
+     * Implicit converter from `Cache` to `ScalarCachePimp` "pimp".
      *
      * @param impl Grid cache to convert.
      */
-    implicit def toScalarCache[K, V](impl: GridCache[K, V]): 
ScalarCachePimp[K, V] =
+    implicit def toScalarCache[K, V](impl: Cache[K, V]): ScalarCachePimp[K, V] 
=
         ScalarCachePimp[K, V](impl)
 
     /**
-     * Implicit converter from `GridCacheProjection` to 
`ScalarCacheProjectionPimp` "pimp".
+     * Implicit converter from `CacheProjection` to 
`ScalarCacheProjectionPimp` "pimp".
      *
      * @param impl Grid cache projection to convert.
      */
-    implicit def toScalarCacheProjection[K, V](impl: GridCacheProjection[K, 
V]): ScalarCacheProjectionPimp[K, V] =
+    implicit def toScalarCacheProjection[K, V](impl: CacheProjection[K, V]): 
ScalarCacheProjectionPimp[K, V] =
         ScalarCacheProjectionPimp[K, V](impl)
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCachePimp.scala
----------------------------------------------------------------------
diff --git 
a/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCachePimp.scala
 
b/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCachePimp.scala
index c5a60f5..94c4ea1 100644
--- 
a/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCachePimp.scala
+++ 
b/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCachePimp.scala
@@ -17,11 +17,11 @@
 
 package org.gridgain.scalar.pimps
 
-import org.apache.ignite.cache.GridCache
+import org.apache.ignite.cache.Cache
 
 /**
  * ==Overview==
- * Defines Scalar "pimp" for `GridCache` on Java side.
+ * Defines Scalar "pimp" for `Cache` on Java side.
  *
  * Essentially this class extends Java `GridProjection` interface with Scala 
specific
  * API adapters using primarily implicit conversions defined in 
`ScalarConversions` object. What
@@ -38,13 +38,13 @@ import org.apache.ignite.cache.GridCache
  * Instead of giving two different names to the same function we've decided to 
simply mark
  * Scala's side method with `$` suffix.
  */
-class ScalarCachePimp[K, V] extends ScalarCacheProjectionPimp[K, V] with 
Ordered[GridCache[K, V]] {
+class ScalarCachePimp[K, V] extends ScalarCacheProjectionPimp[K, V] with 
Ordered[Cache[K, V]] {
     /**
      * Compares this cache name to the given cache name.
      *
      * @param that Another cache instance to compare names with.
      */
-    def compare(that: GridCache[K, V]): Int = that.name.compareTo(value.name)
+    def compare(that: Cache[K, V]): Int = that.name.compareTo(value.name)
 }
 
 /**
@@ -56,7 +56,7 @@ object ScalarCachePimp {
      *
      * @param impl Java-side implementation.
      */
-    def apply[K, V](impl: GridCache[K, V]) = {
+    def apply[K, V](impl: Cache[K, V]) = {
         if (impl == null)
             throw new NullPointerException("impl")
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCacheProjectionPimp.scala
----------------------------------------------------------------------
diff --git 
a/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCacheProjectionPimp.scala
 
b/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCacheProjectionPimp.scala
index 0f268f0..12c91fd 100644
--- 
a/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCacheProjectionPimp.scala
+++ 
b/modules/scalar/src/main/scala/org/apache/ignite/scalar/pimps/ScalarCacheProjectionPimp.scala
@@ -17,7 +17,7 @@
 
 package org.gridgain.scalar.pimps
 
-import org.apache.ignite.cache.{GridCacheEntry, GridCacheProjection}
+import org.apache.ignite.cache.{CacheEntry, CacheProjection}
 import org.apache.ignite.cluster.ClusterGroup
 import org.apache.ignite.lang.{IgnitePredicate, IgniteReducer, IgniteClosure, 
IgniteBiTuple}
 
@@ -39,7 +39,7 @@ object ScalarCacheProjectionPimp {
      *
      * @param impl Java-side implementation.
      */
-    def apply[K, V](impl: GridCacheProjection[K, V]) = {
+    def apply[K, V](impl: CacheProjection[K, V]) = {
         if (impl == null)
             throw new NullPointerException("impl")
 
@@ -53,12 +53,12 @@ object ScalarCacheProjectionPimp {
 
 /**
  * ==Overview==
- * Defines Scalar "pimp" for `GridCacheProjection` on Java side.
+ * Defines Scalar "pimp" for `CacheProjection` on Java side.
  *
- * Essentially this class extends Java `GridCacheProjection` interface with 
Scala specific
+ * Essentially this class extends Java `CacheProjection` interface with Scala 
specific
  * API adapters using primarily implicit conversions defined in 
`ScalarConversions` object. What
  * it means is that you can use functions defined in this class on object
- * of Java `GridCacheProjection` type. Scala will automatically (implicitly) 
convert it into
+ * of Java `CacheProjection` type. Scala will automatically (implicitly) 
convert it into
  * Scalar's pimp and replace the original call with a call on that pimp.
  *
  * Note that Scalar provide extensive library of implicit conversion between 
Java and
@@ -70,16 +70,16 @@ object ScalarCacheProjectionPimp {
  * Instead of giving two different names to the same function we've decided to 
simply mark
  * Scala's side method with `$` suffix.
  */
-class ScalarCacheProjectionPimp[@specialized K, @specialized V] extends 
PimpedType[GridCacheProjection[K, V]]
-    with Iterable[GridCacheEntry[K, V]] {
+class ScalarCacheProjectionPimp[@specialized K, @specialized V] extends 
PimpedType[CacheProjection[K, V]]
+    with Iterable[CacheEntry[K, V]] {
     /** */
-    lazy val value: GridCacheProjection[K, V] = impl
+    lazy val value: CacheProjection[K, V] = impl
 
     /** */
-    protected var impl: GridCacheProjection[K, V] = _
+    protected var impl: CacheProjection[K, V] = _
 
     /** Type alias. */
-    protected type EntryPred = (GridCacheEntry[K, V]) => Boolean
+    protected type EntryPred = (CacheEntry[K, V]) => Boolean
 
     /** Type alias. */
     protected type KvPred = (K, V) => Boolean
@@ -93,7 +93,7 @@ class ScalarCacheProjectionPimp[@specialized K, @specialized 
V] extends PimpedTy
     /**
      * Unwraps sequence of functions to sequence of GridGain predicates.
      */
-    private def unwrap(@Nullable p: Seq[EntryPred]): 
Seq[IgnitePredicate[GridCacheEntry[K, V]]] =
+    private def unwrap(@Nullable p: Seq[EntryPred]): 
Seq[IgnitePredicate[CacheEntry[K, V]]] =
         if (p == null)
             null
         else
@@ -163,7 +163,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * @param p Filter to check prior to getting the value. Note that filter 
check
      *      together with getting the value is an atomic operation.
      * @return Value for the given key.
-     * @see `GridCacheProjection.get(...)`
+     * @see `CacheProjection.get(...)`
      */
     def opt(k: K, p: EntryPred = null): Option[V] =
         Option(value.projection(p).get(k))
@@ -177,9 +177,9 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * @param p Key-value predicate for this projection. If `null`, then the
      *      same projection is returned.
      * @return Projection for given key-value predicate.
-     * @see `GridCacheProjection.projection(...)`
+     * @see `CacheProjection.projection(...)`
      */
-    def viewByKv(@Nullable p: ((K, V) => Boolean)): GridCacheProjection[K, V] =
+    def viewByKv(@Nullable p: ((K, V) => Boolean)): CacheProjection[K, V] =
         if (p == null)
             value
         else
@@ -194,9 +194,9 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *      same projection is returned.  If cache operation receives its own 
filter, then filters
      *      will be `anded`.
      * @return Projection based on given filter.
-     * @see `GridCacheProjection.projection(...)`
+     * @see `CacheProjection.projection(...)`
      */
-    def viewByEntry(@Nullable p: EntryPred): GridCacheProjection[K, V] =
+    def viewByEntry(@Nullable p: EntryPred): CacheProjection[K, V] =
         if (p == null)
             value
         else
@@ -210,17 +210,17 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * it properly converts types from Scala counterparts to Java ones.
      *
      * ===Cache Flags===
-     * The resulting projection will have flag `GridCacheFlag#STRICT` set on 
it.
+     * The resulting projection will have flag `CacheFlag#STRICT` set on it.
      *
      * @param k Key type.
      * @param v Value type.
      * @return Cache projection for given key and value types.
-     * @see `GridCacheProjection.projection(...)`
+     * @see `CacheProjection.projection(...)`
      */
-    def viewByType[A, B](k: Class[A], v: Class[B]): GridCacheProjection[A, B] 
= {
+    def viewByType[A, B](k: Class[A], v: Class[B]): CacheProjection[A, B] = {
         assert(k != null && v != null)
 
-        value.projection(toJavaType(k), 
toJavaType(v)).asInstanceOf[GridCacheProjection[A, B]]
+        value.projection(toJavaType(k), 
toJavaType(v)).asInstanceOf[CacheProjection[A, B]]
     }
 
     /**
@@ -272,13 +272,13 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param kv Key-Value pair to store in cache.
      * @param p Optional filter to check prior to putting value in cache. Note
      *      that filter check is atomic with put operation.
      * @return `True` if value was stored in cache, `false` otherwise.
-     * @see `GridCacheProjection#putx(...)`
+     * @see `CacheProjection#putx(...)`
      */
     def putx$(kv: (K, V), @Nullable p: EntryPred*): Boolean =
         value.putx(kv._1, kv._2, unwrap(p): _*)
@@ -297,7 +297,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param kv Key-Value pair to store in cache.
      * @param p Optional filter to check prior to putting value in cache. Note
@@ -305,7 +305,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * @return Previous value associated with specified key, or `null`
      *      if entry did not pass the filter, or if there was no mapping for 
the key in swap
      *      or in persistent storage.
-     * @see `GridCacheProjection#put(...)`
+     * @see `CacheProjection#put(...)`
      */
     def put$(kv: (K, V), @Nullable p: EntryPred*): V =
         value.put(kv._1, kv._2, unwrap(p): _*)
@@ -324,13 +324,13 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param kv Key-Value pair to store in cache.
      * @param p Optional filter to check prior to putting value in cache. Note
      *      that filter check is atomic with put operation.
      * @return Previous value associated with specified key as an option.
-     * @see `GridCacheProjection#put(...)`
+     * @see `CacheProjection#put(...)`
      */
     def putOpt$(kv: (K, V), @Nullable p: EntryPred*): Option[V] =
         Option(value.put(kv._1, kv._2, unwrap(p): _*))
@@ -342,7 +342,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * @param p Optional filter to check prior to putting value in cache. Note
      *      that filter check is atomic with put operation.
      * @return `True` if value was stored in cache, `false` otherwise.
-     * @see `GridCacheProjection#putx(...)`
+     * @see `CacheProjection#putx(...)`
      */
     def +=(kv: (K, V), @Nullable p: EntryPred*): Boolean =
         putx$(kv, p: _*)
@@ -359,12 +359,12 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param kv1 Key-value pair to store in cache.
      * @param kv2 Key-value pair to store in cache.
      * @param kvs Optional key-value pairs to store in cache.
-     * @see `GridCacheProjection#putAll(...)`
+     * @see `CacheProjection#putAll(...)`
      */
     def putAll$(kv1: (K, V), kv2: (K, V), @Nullable kvs: (K, V)*) {
         var m = mutable.Map.empty[K, V]
@@ -389,10 +389,10 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param kvs Key-value pairs to store in cache. If `null` this function 
is no-op.
-     * @see `GridCacheProjection#putAll(...)`
+     * @see `CacheProjection#putAll(...)`
      */
     def putAll$(@Nullable kvs: Seq[(K, V)]) {
         if (kvs != null)
@@ -411,10 +411,10 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param ks Sequence of additional keys to remove. If `null` - this 
function is no-op.
-     * @see `GridCacheProjection#removeAll(...)`
+     * @see `CacheProjection#removeAll(...)`
      */
     def removeAll$(@Nullable ks: Seq[K]) {
         if (ks != null)
@@ -427,7 +427,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * @param kv1 Key-value pair to store in cache.
      * @param kv2 Key-value pair to store in cache.
      * @param kvs Optional key-value pairs to store in cache.
-     * @see `GridCacheProjection#putAll(...)`
+     * @see `CacheProjection#putAll(...)`
      */
     def +=(kv1: (K, V), kv2: (K, V), @Nullable kvs: (K, V)*) {
         putAll$(kv1, kv2, kvs: _*)
@@ -456,14 +456,14 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param k Key whose mapping is to be removed from cache.
      * @param p Optional filters to check prior to removing value form cache. 
Note
      *      that filter is checked atomically together with remove operation.
      * @return Previous value associated with specified key, or `null`
      *      if there was no value for this key.
-     * @see `GridCacheProjection#remove(...)`
+     * @see `CacheProjection#remove(...)`
      */
     def remove$(k: K, @Nullable p: EntryPred*): V =
         value.remove(k, unwrap(p): _*)
@@ -491,13 +491,13 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param k Key whose mapping is to be removed from cache.
      * @param p Optional filters to check prior to removing value form cache. 
Note
      *      that filter is checked atomically together with remove operation.
      * @return Previous value associated with specified key as an option.
-     * @see `GridCacheProjection#remove(...)`
+     * @see `CacheProjection#remove(...)`
      */
     def removeOpt$(k: K, @Nullable p: EntryPred*): Option[V] =
         Option(value.remove(k, unwrap(p): _*))
@@ -510,7 +510,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *      that filter is checked atomically together with remove operation.
      * @return Previous value associated with specified key, or `null`
      *      if there was no value for this key.
-     * @see `GridCacheProjection#remove(...)`
+     * @see `CacheProjection#remove(...)`
      */
     def -=(k: K, @Nullable p: EntryPred*): V =
         remove$(k, p: _*)
@@ -527,12 +527,12 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * ===Cache Flags===
      * This method is not available if any of the following flags are set on 
projection:
-     * `GridCacheFlag#LOCAL`, `GridCacheFlag#READ`.
+     * `CacheFlag#LOCAL`, `CacheFlag#READ`.
      *
      * @param k1 1st key to remove.
      * @param k2 2nd key to remove.
      * @param ks Optional sequence of additional keys to remove.
-     * @see `GridCacheProjection#removeAll(...)`
+     * @see `CacheProjection#removeAll(...)`
      */
     def removeAll$(k1: K, k2: K, @Nullable ks: K*) {
         val s = new mutable.ArrayBuffer[K](2 + (if (ks == null) 0 else 
ks.length))
@@ -552,7 +552,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * @param k1 1st key to remove.
      * @param k2 2nd key to remove.
      * @param ks Optional sequence of additional keys to remove.
-     * @see `GridCacheProjection#removeAll(...)`
+     * @see `CacheProjection#removeAll(...)`
      */
     def -=(k1: K, k2: K, @Nullable ks: K*) {
         removeAll$(k1, k2, ks: _*)
@@ -572,7 +572,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def scan(@Nullable grid: ClusterGroup = null, cls: Class[_ <: V], kvp: 
KvPred): Iterable[(K, V)] = {
@@ -599,7 +599,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def scan(@Nullable grid: ClusterGroup, kvp: KvPred)
@@ -621,7 +621,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def scan(cls: Class[_ <: V], kvp: KvPred): Iterable[(K, V)] = {
@@ -644,7 +644,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def scan(kvp: KvPred)(implicit m: Manifest[V]): Iterable[(K, V)] = {
@@ -667,7 +667,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
      */
@@ -697,7 +697,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def sql(@Nullable grid: ClusterGroup = null, cls: Class[_ <: V], clause: 
String): Iterable[(K, V)] = {
@@ -722,7 +722,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
      */
@@ -746,7 +746,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
      */
@@ -770,7 +770,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
      */
@@ -794,7 +794,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def text(@Nullable grid: ClusterGroup = null, cls: Class[_ <: V], clause: 
String): Iterable[(K, V)] = {
@@ -821,7 +821,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def text(@Nullable grid: ClusterGroup, clause: String)(implicit m: 
Manifest[V]): Iterable[(K, V)] = {
@@ -842,7 +842,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def text(cls: Class[_ <: V], clause: String): Iterable[(K, V)] = {
@@ -865,7 +865,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @return Collection of cache key-value pairs.
      */
     def text(clause: String)(implicit m: Manifest[V]): Iterable[(K, V)] = {
@@ -888,7 +888,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -917,7 +917,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * cache projection.
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the global projection will be used.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -941,7 +941,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -966,7 +966,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -992,7 +992,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
@@ -1024,7 +1024,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -1052,7 +1052,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
@@ -1078,7 +1078,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
@@ -1105,7 +1105,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @param args Optional list of query arguments.
      * @return Collection of cache key-value pairs.
@@ -1133,7 +1133,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -1163,7 +1163,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -1187,7 +1187,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -1212,7 +1212,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param trans Transform function that will be applied to each returned 
value.
      * @return Collection of cache key-value pairs.
      */
@@ -1238,7 +1238,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1270,7 +1270,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1296,7 +1296,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1324,7 +1324,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1352,7 +1352,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @param args Optional list of query arguments.
@@ -1386,7 +1386,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1416,7 +1416,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @param args Optional list of query arguments.
@@ -1444,7 +1444,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @param args Optional list of query arguments.
@@ -1474,7 +1474,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @param args Optional list of query arguments.
@@ -1504,7 +1504,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1536,7 +1536,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1562,7 +1562,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1590,7 +1590,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param locRdc Reduce function that will be called on local node.
      * @return Reduced value.
@@ -1618,7 +1618,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1647,7 +1647,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * cache projection.
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the global projection will be used.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1671,7 +1671,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1696,7 +1696,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `GridCacheQuery` for more details.
+     * @param kvp Filter to be used prior to returning key-value pairs to 
user. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1721,7 +1721,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param args Optional list of query arguments.
      * @return Collection of reduced values.
@@ -1753,7 +1753,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1781,7 +1781,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param args Optional list of query arguments.
      * @return Collection of reduced values.
@@ -1807,7 +1807,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param args Optional list of query arguments.
      * @return Collection of reduced values.
@@ -1835,7 +1835,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @param args Optional list of query arguments.
      * @return Collection of reduced values.
@@ -1863,7 +1863,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *     global projection will be used.
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1893,7 +1893,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Grid projection on which this query will be executed. If 
`null` the
      *     global projection will be used.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1917,7 +1917,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param cls Query values class. Since cache can, in general, contain 
values of any subtype of `V`
      *     query needs to know the exact type it should operate on.
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1943,7 +1943,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      * Note that query value class will be taken implicitly as exact type `V` 
of this
      * cache projection.
      *
-     * @param clause Query text clause. See `GridCacheQuery` for more details.
+     * @param clause Query text clause. See `CacheQuery` for more details.
      * @param rmtRdc Reduce function that will be called on each remote node.
      * @return Collection of reduced values.
      */
@@ -1967,7 +1967,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Optional grid projection on which this query will be 
executed. If `null` the
      *      global projection will be used.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @param args Optional list of query arguments.
      * @return Sequence of sequences of field values.
      */
@@ -1993,7 +1993,7 @@ class ScalarCacheProjectionPimp[@specialized K, 
@specialized V] extends PimpedTy
      *
      * @param grid Optional grid projection on which this query will be 
executed. If `null` the
      *      global projection will be used.
-     * @param clause Query SQL clause. See `GridCacheQuery` for more details.
+     * @param clause Query SQL clause. See `CacheQuery` for more details.
      * @return Sequence of sequences of field values.
      */
     def sqlFields(@Nullable grid: ClusterGroup = null, clause: String): 
IndexedSeq[IndexedSeq[Any]] = {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/scalar/src/main/scala/org/apache/ignite/scalar/scalar.scala
----------------------------------------------------------------------
diff --git 
a/modules/scalar/src/test/scala/org/apache/ignite/scalar/tests/ScalarCacheQueriesSpec.scala
 
b/modules/scalar/src/test/scala/org/apache/ignite/scalar/tests/ScalarCacheQueriesSpec.scala
index 0bc66ea..21426e0 100644
--- 
a/modules/scalar/src/test/scala/org/apache/ignite/scalar/tests/ScalarCacheQueriesSpec.scala
+++ 
b/modules/scalar/src/test/scala/org/apache/ignite/scalar/tests/ScalarCacheQueriesSpec.scala
@@ -17,7 +17,7 @@
 
 package org.gridgain.scalar.tests
 
-import org.apache.ignite.cache.GridCache
+import org.apache.ignite.cache.Cache
 import org.apache.ignite.cluster.ClusterNode
 import org.gridgain.scalar._
 import scalar._
@@ -41,7 +41,7 @@ class ScalarCacheQueriesSpec extends FlatSpec with 
ShouldMatchers with BeforeAnd
     private var n: ClusterNode = null
 
     /** Cache. */
-    private var c: GridCache[Int, ObjectValue] = null
+    private var c: Cache[Int, ObjectValue] = null
 
     /**
      * Start node and put data to cache.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/spring/src/main/java/org/apache/ignite/IgniteSpringBean.java
----------------------------------------------------------------------
diff --git 
a/modules/spring/src/main/java/org/apache/ignite/IgniteSpringBean.java 
b/modules/spring/src/main/java/org/apache/ignite/IgniteSpringBean.java
index 94d7116..95b5e57 100644
--- a/modules/spring/src/main/java/org/apache/ignite/IgniteSpringBean.java
+++ b/modules/spring/src/main/java/org/apache/ignite/IgniteSpringBean.java
@@ -137,7 +137,7 @@ public class IgniteSpringBean implements Ignite, 
DisposableBean, InitializingBea
     }
 
     /** {@inheritDoc} */
-    @Override public Collection<GridCache<?, ?>> caches() {
+    @Override public Collection<Cache<?, ?>> caches() {
         assert g != null;
 
         return g.caches();
@@ -256,7 +256,7 @@ public class IgniteSpringBean implements Ignite, 
DisposableBean, InitializingBea
     }
 
     /** {@inheritDoc} */
-    @Override public <K, V> GridCache<K, V> cache(String name) {
+    @Override public <K, V> Cache<K, V> cache(String name) {
         assert g != null;
 
         return g.cache(name);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCache.java
----------------------------------------------------------------------
diff --git 
a/modules/scalar/src/main/scala/org/apache/ignite/scalar/scalar.scala 
b/modules/scalar/src/main/scala/org/apache/ignite/scalar/scalar.scala
index 83f04ee..345aa37 100644
--- a/modules/scalar/src/main/scala/org/apache/ignite/scalar/scalar.scala
+++ b/modules/scalar/src/main/scala/org/apache/ignite/scalar/scalar.scala
@@ -18,8 +18,8 @@
 package org.gridgain.scalar
 
 import java.net.URL
-import org.apache.ignite.cache.GridCache
-import org.apache.ignite.cache.query.{GridCacheQuerySqlField, 
GridCacheQueryTextField}
+import org.apache.ignite.cache.Cache
+import org.apache.ignite.cache.query.{CacheQuerySqlField, CacheQueryTextField}
 import org.apache.ignite.internal.GridProductImpl
 import org.apache.ignite.{IgniteState, IgniteDataLoader, Ignition, Ignite}
 import org.apache.ignite.cluster.ClusterNode
@@ -128,11 +128,11 @@ object scalar extends ScalarConversions {
     /** Visor copyright blurb. */
     private val COPYRIGHT = GridProductImpl.COPYRIGHT
 
-    /** Type alias for `GridCacheQuerySqlField`. */
-    type ScalarCacheQuerySqlField = GridCacheQuerySqlField @field
+    /** Type alias for `CacheQuerySqlField`. */
+    type ScalarCacheQuerySqlField = CacheQuerySqlField @field
 
-    /** Type alias for `GridCacheQueryTextField`. */
-    type ScalarCacheQueryTextField = GridCacheQueryTextField @field
+    /** Type alias for `CacheQueryTextField`. */
+    type ScalarCacheQueryTextField = CacheQueryTextField @field
 
     /**
      * Prints Scalar ASCII-logo.
@@ -262,10 +262,10 @@ object scalar extends ScalarConversions {
      * Gets default cache.
      *
      * Note that you always need to provide types when calling
-     * this function - otherwise Scala will create `GridCache[Nothing, 
Nothing]`
+     * this function - otherwise Scala will create `Cache[Nothing, Nothing]`
      * typed instance that cannot be used.
      */
-    @inline def cache$[K, V]: Option[GridCache[K, V]] =
+    @inline def cache$[K, V]: Option[Cache[K, V]] =
         Option(Ignition.ignite.cache[K, V](null))
 
     /**
@@ -273,7 +273,7 @@ object scalar extends ScalarConversions {
      *
      * @param cacheName Name of the cache to get.
      */
-    @inline def cache$[K, V](@Nullable cacheName: String): Option[GridCache[K, 
V]] =
+    @inline def cache$[K, V](@Nullable cacheName: String): Option[Cache[K, V]] 
=
         Option(Ignition.ignite.cache(cacheName))
 
     /**
@@ -282,7 +282,7 @@ object scalar extends ScalarConversions {
      * @param gridName Name of the grid.
      * @param cacheName Name of the cache to get.
      */
-    @inline def cache$[K, V](@Nullable gridName: String, @Nullable cacheName: 
String): Option[GridCache[K, V]] =
+    @inline def cache$[K, V](@Nullable gridName: String, @Nullable cacheName: 
String): Option[Cache[K, V]] =
         grid$(gridName) match {
             case Some(g) => Option(g.cache(cacheName))
             case None => None

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/scalar/src/test/scala/org/apache/ignite/scalar/tests/ScalarCacheQueriesSpec.scala
----------------------------------------------------------------------
diff --git 
a/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCache.java 
b/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCache.java
index b372117..9ab975a 100644
--- 
a/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCache.java
+++ 
b/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCache.java
@@ -21,7 +21,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.cache.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.typedef.*;
-import org.springframework.cache.*;
 import org.springframework.cache.support.*;
 
 import java.io.*;
@@ -37,7 +36,7 @@ class SpringCache implements Cache, Serializable {
     private Ignite ignite;
 
     /** */
-    private GridCacheProjection<Object, Object> cache;
+    private CacheProjection<Object, Object> cache;
 
     /** */
     private IgniteClosure<Object, Object> keyFactory;
@@ -48,13 +47,13 @@ class SpringCache implements Cache, Serializable {
      * @param cache Cache.
      * @param keyFactory Key factory.
      */
-    SpringCache(String name, Ignite ignite, GridCacheProjection<?, ?> cache,
+    SpringCache(String name, Ignite ignite, CacheProjection<?, ?> cache,
                 IgniteClosure<Object, Object> keyFactory) {
         assert cache != null;
 
         this.name = name;
         this.ignite = ignite;
-        this.cache = (GridCacheProjection<Object, Object>)cache;
+        this.cache = (CacheProjection<Object, Object>)cache;
         this.keyFactory = keyFactory != null ? keyFactory : F.identity();
     }
 
@@ -151,7 +150,7 @@ class SpringCache implements Cache, Serializable {
         private static final long serialVersionUID = 0L;
 
         /** Cache projection. */
-        private GridCacheProjection<Object, Object> cache;
+        private CacheProjection<Object, Object> cache;
 
         /**
          * For {@link Externalizable}.
@@ -163,7 +162,7 @@ class SpringCache implements Cache, Serializable {
         /**
          * @param cache Cache projection.
          */
-        private ClearClosure(GridCacheProjection<Object, Object> cache) {
+        private ClearClosure(CacheProjection<Object, Object> cache) {
             this.cache = cache;
         }
 
@@ -179,7 +178,7 @@ class SpringCache implements Cache, Serializable {
 
         /** {@inheritDoc} */
         @Override public void readExternal(ObjectInput in) throws IOException, 
ClassNotFoundException {
-            cache = (GridCacheProjection<Object, Object>)in.readObject();
+            cache = (CacheProjection<Object, Object>)in.readObject();
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCacheManager.java
----------------------------------------------------------------------
diff --git 
a/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCacheManager.java
 
b/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCacheManager.java
index d8cb69c..a671b36 100644
--- 
a/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCacheManager.java
+++ 
b/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringCacheManager.java
@@ -18,7 +18,7 @@
 package org.apache.ignite.cache.spring;
 
 import org.apache.ignite.*;
-import org.apache.ignite.cache.*;
+import org.apache.ignite.cache.Cache;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.typedef.*;
@@ -217,7 +217,7 @@ public class SpringCacheManager implements CacheManager, 
InitializingBean {
     }
 
     /** {@inheritDoc} */
-    @Override public Cache getCache(String name) {
+    @Override public org.springframework.cache.Cache getCache(String name) {
         assert grid != null;
 
         try {
@@ -232,8 +232,8 @@ public class SpringCacheManager implements CacheManager, 
InitializingBean {
     @Override public Collection<String> getCacheNames() {
         assert grid != null;
 
-        return F.viewReadOnly(grid.caches(), new IgniteClosure<GridCache<?,?>, 
String>() {
-            @Override public String apply(GridCache<?, ?> c) {
+        return F.viewReadOnly(grid.caches(), new IgniteClosure<Cache<?,?>, 
String>() {
+            @Override public String apply(Cache<?, ?> c) {
                 return c.name();
             }
         });

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringDynamicCacheManager.java
----------------------------------------------------------------------
diff --git 
a/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringDynamicCacheManager.java
 
b/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringDynamicCacheManager.java
index 821b3e7..608f800 100644
--- 
a/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringDynamicCacheManager.java
+++ 
b/modules/spring/src/main/java/org/apache/ignite/cache/spring/SpringDynamicCacheManager.java
@@ -18,14 +18,13 @@
 package org.apache.ignite.cache.spring;
 
 import org.apache.ignite.*;
-import org.apache.ignite.cache.*;
+import org.apache.ignite.cache.Cache;
 import org.apache.ignite.internal.*;
 import org.apache.ignite.internal.processors.cache.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.internal.util.tostring.*;
 import org.apache.ignite.internal.util.typedef.*;
 import org.apache.ignite.internal.util.typedef.internal.*;
-import org.springframework.cache.*;
 import org.springframework.cache.annotation.*;
 
 import java.io.*;
@@ -77,10 +76,10 @@ public class SpringDynamicCacheManager extends 
SpringCacheManager {
     private String dataCacheName;
 
     /** Meta cache. */
-    private GridCacheProjectionEx<MetaKey, Cache> metaCache;
+    private GridCacheProjectionEx<MetaKey, org.springframework.cache.Cache> 
metaCache;
 
     /** Data cache. */
-    private GridCache<DataKey, Object> dataCache;
+    private Cache<DataKey, Object> dataCache;
 
     /**
      * Sets data cache name.
@@ -104,13 +103,13 @@ public class SpringDynamicCacheManager extends 
SpringCacheManager {
     @Override public void afterPropertiesSet() throws Exception {
         super.afterPropertiesSet();
 
-        metaCache = ((GridEx)grid).utilityCache(MetaKey.class, Cache.class);
+        metaCache = ((GridEx)grid).utilityCache(MetaKey.class, 
org.springframework.cache.Cache.class);
         dataCache = grid.cache(dataCacheName);
     }
 
     /** {@inheritDoc} */
-    @Override public Cache getCache(final String name) {
-        Cache cache = super.getCache(name);
+    @Override public org.springframework.cache.Cache getCache(final String 
name) {
+        org.springframework.cache.Cache cache = super.getCache(name);
 
         if (cache != null)
             return cache;
@@ -128,7 +127,7 @@ public class SpringDynamicCacheManager extends 
SpringCacheManager {
                         }
                     });
 
-                Cache old = metaCache.putIfAbsent(key, cache);
+                org.springframework.cache.Cache old = 
metaCache.putIfAbsent(key, cache);
 
                 if (old != null)
                     cache = old;
@@ -150,8 +149,8 @@ public class SpringDynamicCacheManager extends 
SpringCacheManager {
         });
 
         return F.concat(false, names, F.transform(metaCache.entrySetx(),
-            new IgniteClosure<Map.Entry<MetaKey, Cache>, String>() {
-                @Override public String apply(Map.Entry<MetaKey, Cache> e) {
+            new IgniteClosure<Map.Entry<MetaKey, 
org.springframework.cache.Cache>, String>() {
+                @Override public String apply(Map.Entry<MetaKey, 
org.springframework.cache.Cache> e) {
                     return e.getKey().name;
                 }
             }));

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/spring/src/test/java/org/apache/ignite/p2p/GridP2PUserVersionChangeSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/spring/src/test/java/org/apache/ignite/p2p/GridP2PUserVersionChangeSelfTest.java
 
b/modules/spring/src/test/java/org/apache/ignite/p2p/GridP2PUserVersionChangeSelfTest.java
index 4152113..e827e3c 100644
--- 
a/modules/spring/src/test/java/org/apache/ignite/p2p/GridP2PUserVersionChangeSelfTest.java
+++ 
b/modules/spring/src/test/java/org/apache/ignite/p2p/GridP2PUserVersionChangeSelfTest.java
@@ -289,13 +289,13 @@ public class GridP2PUserVersionChangeSelfTest extends 
GridCommonAbstractTest {
 
             Class rcrsCls = ldr.loadClass(TEST_RCRS_NAME);
 
-            GridCache<Long, Object> cache1 = ignite1.cache(null);
+            Cache<Long, Object> cache1 = ignite1.cache(null);
 
             assertNotNull(cache1);
 
             cache1.put(1L, rcrsCls.newInstance());
 
-            final GridCache<Long, Object> cache2 = ignite2.cache(null);
+            final Cache<Long, Object> cache2 = ignite2.cache(null);
 
             assertNotNull(cache2);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringCacheManagerSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringCacheManagerSelfTest.java
 
b/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringCacheManagerSelfTest.java
index 1d888c4..a4a460b 100644
--- 
a/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringCacheManagerSelfTest.java
+++ 
b/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringCacheManagerSelfTest.java
@@ -98,7 +98,7 @@ public class GridSpringCacheManagerSelfTest extends 
GridCommonAbstractTest {
 
         assertEquals(3, svc.called());
 
-        GridCache<Integer, String> c = grid().cache(CACHE_NAME);
+        Cache<Integer, String> c = grid().cache(CACHE_NAME);
 
         assertEquals(3, c.size());
 
@@ -117,7 +117,7 @@ public class GridSpringCacheManagerSelfTest extends 
GridCommonAbstractTest {
 
         assertEquals(3, svc.called());
 
-        GridCache<GridSpringCacheTestKey, String> c = grid().cache(CACHE_NAME);
+        Cache<GridSpringCacheTestKey, String> c = grid().cache(CACHE_NAME);
 
         assertEquals(3, c.size());
 
@@ -129,7 +129,7 @@ public class GridSpringCacheManagerSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testSimpleKeyPut() throws Exception {
-        GridCache<Integer, String> c = grid().cache(CACHE_NAME);
+        Cache<Integer, String> c = grid().cache(CACHE_NAME);
 
         for (int i = 0; i < 3; i++) {
             assertEquals("value" + i + "odd", svc.simpleKeyPut(i));
@@ -150,7 +150,7 @@ public class GridSpringCacheManagerSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testComplexKeyPut() throws Exception {
-        GridCache<GridSpringCacheTestKey, String> c = grid().cache(CACHE_NAME);
+        Cache<GridSpringCacheTestKey, String> c = grid().cache(CACHE_NAME);
 
         for (int i = 0; i < 3; i++) {
             assertEquals("value" + i + "suffix" + i + "odd", 
svc.complexKeyPut(i, "suffix" + i));
@@ -171,7 +171,7 @@ public class GridSpringCacheManagerSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testSimpleKeyEvict() throws Exception {
-        GridCache<Integer, String> c = grid().cache(CACHE_NAME);
+        Cache<Integer, String> c = grid().cache(CACHE_NAME);
 
         for (int i = 0; i < 3; i++)
             c.putx(i, "value" + i);
@@ -195,7 +195,7 @@ public class GridSpringCacheManagerSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testComplexKeyEvict() throws Exception {
-        GridCache<GridSpringCacheTestKey, String> c = grid().cache(CACHE_NAME);
+        Cache<GridSpringCacheTestKey, String> c = grid().cache(CACHE_NAME);
 
         for (int i = 0; i < 3; i++)
             c.putx(new GridSpringCacheTestKey(i, "suffix" + i), "value" + i);
@@ -219,7 +219,7 @@ public class GridSpringCacheManagerSelfTest extends 
GridCommonAbstractTest {
      * @throws Exception If failed.
      */
     public void testEvictAll() throws Exception {
-        GridCache<Integer, String> c = grid().cache(CACHE_NAME);
+        Cache<Integer, String> c = grid().cache(CACHE_NAME);
 
         for (int i = 0; i < 3; i++)
             c.putx(i, "value" + i);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringDynamicCacheManagerSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringDynamicCacheManagerSelfTest.java
 
b/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringDynamicCacheManagerSelfTest.java
index 545bf5b..e41e93e 100644
--- 
a/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringDynamicCacheManagerSelfTest.java
+++ 
b/modules/spring/src/test/java/org/apache/ignite/spring/GridSpringDynamicCacheManagerSelfTest.java
@@ -18,6 +18,7 @@
 package org.apache.ignite.spring;
 
 import org.apache.ignite.cache.*;
+import org.apache.ignite.cache.Cache;
 import org.apache.ignite.cache.spring.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.spi.discovery.tcp.*;
@@ -110,7 +111,7 @@ public class GridSpringDynamicCacheManagerSelfTest extends 
GridCommonAbstractTes
      * @throws Exception If failed.
      */
     public void testCacheAndEvict() throws Exception {
-        GridCache<Object, String> c = grid().cache(DATA_CACHE_NAME);
+        Cache<Object, String> c = grid().cache(DATA_CACHE_NAME);
 
         assertEquals("value1", svc.cacheable(1));
 
@@ -131,7 +132,7 @@ public class GridSpringDynamicCacheManagerSelfTest extends 
GridCommonAbstractTes
      * @throws Exception If failed.
      */
     public void testPutAndEvict() throws Exception {
-        GridCache<Object, String> c = grid().cache(DATA_CACHE_NAME);
+        Cache<Object, String> c = grid().cache(DATA_CACHE_NAME);
 
         assertEquals("value1", svc.cachePut(1));
 
@@ -152,7 +153,7 @@ public class GridSpringDynamicCacheManagerSelfTest extends 
GridCommonAbstractTes
      * @throws Exception If failed.
      */
     public void testCacheAndEvictAll() throws Exception {
-        GridCache<Object, String> c = grid().cache(DATA_CACHE_NAME);
+        Cache<Object, String> c = grid().cache(DATA_CACHE_NAME);
 
         assertEquals("value1", svc.cacheable(1));
         assertEquals("value2", svc.cacheable(2));
@@ -179,7 +180,7 @@ public class GridSpringDynamicCacheManagerSelfTest extends 
GridCommonAbstractTes
      * @throws Exception If failed.
      */
     public void testPutAndEvictAll() throws Exception {
-        GridCache<Object, String> c = grid().cache(DATA_CACHE_NAME);
+        Cache<Object, String> c = grid().cache(DATA_CACHE_NAME);
 
         assertEquals("value1", svc.cachePut(1));
         assertEquals("value2", svc.cachePut(2));

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/visor-console/src/test/scala/org/apache/ignite/visor/commands/cache/VisorCacheCommandSpec.scala
----------------------------------------------------------------------
diff --git 
a/modules/visor-console/src/test/scala/org/apache/ignite/visor/commands/cache/VisorCacheCommandSpec.scala
 
b/modules/visor-console/src/test/scala/org/apache/ignite/visor/commands/cache/VisorCacheCommandSpec.scala
index c46b915..1920f17 100644
--- 
a/modules/visor-console/src/test/scala/org/apache/ignite/visor/commands/cache/VisorCacheCommandSpec.scala
+++ 
b/modules/visor-console/src/test/scala/org/apache/ignite/visor/commands/cache/VisorCacheCommandSpec.scala
@@ -18,7 +18,7 @@
 package org.apache.ignite.visor.commands.cache
 
 import org.apache.ignite.Ignition
-import org.apache.ignite.cache.query.GridCacheQuerySqlField
+import org.apache.ignite.cache.query.CacheQuerySqlField
 import org.apache.ignite.visor.visor
 import org.scalatest._
 
@@ -97,6 +97,6 @@ class VisorCacheCommandSpec extends FlatSpec with Matchers 
with BeforeAndAfterAl
  * Object for queries.
  */
 private case class Foo(
-    @GridCacheQuerySqlField
+    @CacheQuerySqlField
     value: Int
 )

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/web/src/main/java/org/apache/ignite/cache/websession/GridWebSessionFilter.java
----------------------------------------------------------------------
diff --git 
a/modules/web/src/main/java/org/apache/ignite/cache/websession/GridWebSessionFilter.java
 
b/modules/web/src/main/java/org/apache/ignite/cache/websession/GridWebSessionFilter.java
index 91af221..6839380 100644
--- 
a/modules/web/src/main/java/org/apache/ignite/cache/websession/GridWebSessionFilter.java
+++ 
b/modules/web/src/main/java/org/apache/ignite/cache/websession/GridWebSessionFilter.java
@@ -36,7 +36,7 @@ import static org.apache.ignite.cache.CacheAtomicityMode.*;
 import static org.apache.ignite.cache.CacheMode.*;
 import static org.apache.ignite.transactions.IgniteTxConcurrency.*;
 import static org.apache.ignite.transactions.IgniteTxIsolation.*;
-import static org.apache.ignite.cache.GridCacheWriteSynchronizationMode.*;
+import static org.apache.ignite.cache.CacheWriteSynchronizationMode.*;
 
 /**
  * Filter for web sessions caching.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/cafee25f/modules/web/src/test/java/org/apache/ignite/internal/websession/WebSessionSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/web/src/test/java/org/apache/ignite/internal/websession/WebSessionSelfTest.java
 
b/modules/web/src/test/java/org/apache/ignite/internal/websession/WebSessionSelfTest.java
index 7b99774..50be722 100644
--- 
a/modules/web/src/test/java/org/apache/ignite/internal/websession/WebSessionSelfTest.java
+++ 
b/modules/web/src/test/java/org/apache/ignite/internal/websession/WebSessionSelfTest.java
@@ -86,7 +86,7 @@ public class WebSessionSelfTest extends 
GridCommonAbstractTest {
             try (BufferedReader rdr = new BufferedReader(new 
InputStreamReader(conn.getInputStream()))) {
                 String sesId = rdr.readLine();
 
-                GridCache<String, HttpSession> cache = 
G.ignite().cache(getCacheName());
+                Cache<String, HttpSession> cache = 
G.ignite().cache(getCacheName());
 
                 assertNotNull(cache);
 

Reply via email to